@@ -56,7 +56,7 @@ class RestAPI(object):
 				"email":True,
 			},
 		}
-		
+
 
 		"""
 		The plans.
@@ -389,7 +389,16 @@ class RestAPI(object):
 		__uid_api_keys__ = {}
 
 		# iterate users.
-		for user in self.firebase.users.iterate():
+		# do by firestore because new users are missed by firebase iteration for a few minutes.
+		firebase_users = self.firebase.users.iterate()
+		firestore_users = self.firebase.users.iterate(by_firestore=True)
+		_users_, _user_emails_ = [], []
+		for l_users in [firestore_users, firebase_users]:
+			for user in l_users:
+				if user.email not in _user_emails_: 
+					_users_.append(user)
+					_user_emails_.append(user.email)
+		for user in _users_: 
 
 			# load data.
 			uid = user.email # <-- NOTE THE CHANGE OF SAVING USERS BY (email) INSTEAD OF BY (uid).
